@@ -1,11 +1,16 @@
 # -*- coding: utf-8 -*-
 
+from __future__ import unicode_literals
+
+from builtins import str
+
 from email.parser import Parser
 from email.utils import getaddresses
 try:
     from email.headerregistry import Address
 except ImportError:
     from compat import Address
+from io import StringIO
 
 
 __all__ = [
@@ -18,7 +23,8 @@ def parse(s):
 
 
 def parse_list(s):
-    headers = Parser().parsestr('To: {}'.format(s))
+    s = str(s)
+    headers = Parser().parse(StringIO('To: {}'.format(s)))
     addresses = []
     address = None
     for display_name, addr_spec in getaddresses(headers.get_all('to', [])):
